package com.example.ogata.watchfacesample;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.support.wearable.view.WatchViewStub;
import android.util.Log;
import android.view.View;
import android.widget.TextView;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Locale;
import java.util.TimeZone;

public class WatchFaceActivity extends Activity {
    private final String TAG = "TEST";
    private TextView mTextViewDay;
    private boolean mAmbientMode;
    private final IntentFilter mFilter = new IntentFilter();
    private final BroadcastReceiver mReceiver = new BroadcastReceiver() {
        {
            mFilter.addAction("com.google.android.clockwork.home.action.BACKGROUND_ACTION");
            mFilter.addAction(Intent.ACTION_TIME_TICK);
            mFilter.addAction(Intent.ACTION_TIME_CHANGED);
            mFilter.addAction(Intent.ACTION_TIMEZONE_CHANGED);
            mFilter.addAction(Intent.ACTION_DATE_CHANGED);
        }
        private final String AMBIENT_MODE = "ambient_mode";
        @Override
        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            if (Intent.ACTION_TIME_TICK.equals(action) ||
                    Intent.ACTION_TIME_CHANGED.equals(action) ||
                    Intent.ACTION_DATE_CHANGED.equals(action) ||
                    Intent.ACTION_TIMEZONE_CHANGED.equals(action)) {
                displayToday();
                return;
            }

            if (intent.hasExtra(AMBIENT_MODE)) {
                mAmbientMode = intent.getBooleanExtra(AMBIENT_MODE, false);
                Log.d(TAG, AMBIENT_MODE + "=" + mAmbientMode);
                updateAmbientMode();
            }
        }
    };

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        registerReceiver(mReceiver, mFilter);
        setContentView(R.layout.activity_watch_face);
        final WatchViewStub stub = (WatchViewStub) findViewById(R.id.watch_view_stub);
        stub.setOnLayoutInflatedListener(new WatchViewStub.OnLayoutInflatedListener() {
            @Override
            public void onLayoutInflated(WatchViewStub stub) {
                mTextViewDay = (TextView) stub.findViewById(R.id.textViewDay);
                displayToday();
                updateAmbientMode();
            }
        });
    }

    private void displayToday() {
        if (mTextViewDay != null) {
            Calendar calendar = Calendar.getInstance(TimeZone.getDefault());
            DateFormat df;
            if (Locale.getDefault().equals(Locale.JAPAN)) {
                df = new SimpleDateFormat("'" + getEraNameAndYear(calendar) + "' MM'月'dd'日' (E)");
            } else {
                df = new SimpleDateFormat("EEE MMM dd");
            }
            mTextViewDay.setText(df.format(calendar.getTime()));
        }
    }

    private void updateAmbientMode() {
        if (mTextViewDay != null) {
            mTextViewDay.setVisibility(mAmbientMode ? View.INVISIBLE : View.VISIBLE);
        }
    }

    private String getEraNameAndYear(Calendar calendar) {
        // 簡単のため平成以降しか計算しない
        return "平成" + (calendar.get(Calendar.YEAR) - 1988) + "年";
    }
}
